@@ -1,13 +1,13 @@
 read.convert_1_2 <- function(proc.length)
 {
 
-version<-read.table("wave_cor_mat_level_1.txt",skip=0,nrow=1)
+version<-read.table("wave_cor_mat_level_1.txt",skip=0,nrows=1)
 
-tmp<-read.table("wave_cor_mat_level_1.txt",skip=1,nrow=1)
+tmp<-read.table("wave_cor_mat_level_1.txt",skip=1,nrows=1)
 
 if(tmp[[2]]!="Correlation") stop("The files are not of class correlation matrix")
 
-tmp<-read.table("wave_cor_mat_level_1.txt",skip=2,nrow=1)
+tmp<-read.table("wave_cor_mat_level_1.txt",skip=2,nrows=1)
 method<-tmp[[1]]
 wf<-tmp[[2]]
 boundary<-tmp[[3]]
